(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     57941,       1645]*)
(*NotebookOutlinePosition[     82287,       2530]*)
(*  CellTagsIndexPosition[     82179,       2523]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["Mathematica 4.1",
    FontSize->18,
    FontSlant->"Italic",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[" Notebooks\n(c) John H. Mathews, and\nRussell W. Howell, 2001",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["Complimentary software to accompany our textbook:",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]]
}], "Text",
  Evaluatable->False,
  TextAlignment->Center,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["COMPLEX ANALYSIS: for Mathematics and Engineering, \n4th Edition, \
 2001,  ISBN: ",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["0-7637-1425-9",
    FontFamily->"Times New Roman",
    FontSize->18,
    FontColor->RGBColor[0, 0, 0.996109]],
  StyleBox["\n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 1]],
  StyleBox[ButtonBox["Jones & Bartlett Publishers, Inc.",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[" ",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 0]],
  StyleBox[" \n",
    FontSize->18,
    FontColor->RGBColor[0, 1, 0]],
  StyleBox["40 Tall Pine Drive, Sudbury, MA 01776  \nTele.  (800) 832-0034, \
FAX:  (508)  443-8000  \nE-mail:  mkt@jbpub.com  \nInternet:  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["http://www.jbpub.com/",
    ButtonData:>{
      URL[ "http://www.jbpub.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  StyleBox["  ",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontSize->14],
  StyleBox["This free software is compliments of the authors.\n",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["John H. Mathews",
    ButtonData:>{
      URL[ "http://www.ecs.fullerton.edu/~mathews/"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[",   ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["mathews@fullerton.edu ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["\n",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  ButtonBox["Russell W. Howell",
    ButtonData:>{
      URL[ "http://homepage.westmont.edu/~howell/"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[",  ",
    FontSize->14,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["howell@westmont.edu ",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["CHAPTER 4",
    FontSize->18,
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->18],
  StyleBox["SEQUENCES, JULIA and MANDELBROT SETS, and POWER SERIES",
    FontSize->18,
    FontColor->RGBColor[1, 0, 1]]
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  CellTags->"CHAPTER 4"],

Cell[BoxData[{
    \(\(c = \(q = \(S = \(t = \(x = \(y = \(z = 
                    0\)\)\)\)\)\);\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[a, absZn, c, cx, cy, dot, i, juliaC, k, lim, limX, limY, limZ, 
        list, mandelbrotC, n, newton, Pn, q, Qn, R, s, S, Sn, set, sum, sumN, 
        sumX, sumY, sumZ, t, table, x, Xn, y, Yn, z, Z, 
        Zn];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`ComplexMap`\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Needs["\<Graphics`Colors`\>"];\)\ \)}], "Input",
  InitializationCell->True]
}, Closed]],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".1",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Sequences and Series",
    ButtonData:>{"ca0401.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  StyleBox["Section 4.2",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  "  ",
  StyleBox["Julia and Mandelbrot Sets",
    FontColor->RGBColor[0.500008, 0, 0.996109]],
  Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0001f80@0006@000000000000001D0000E0000
00000000001?0`00C`<00215CDH00040R1d001@00002000000000000002l000080<005P200100@00
l000000000000000000004H0003H3000bP`004M4BD<1002000<00393]ST00000/P`000402@000eT6
00010284000000T0000V1Pl0201OATeBBE@Y80<0000N00D0000;0P0000050000308O01l01@800?L0
00<00@00001gMgL0EEEE0<`0b`3^k^h0IP1U0?g;0028R8P006Gm0?ooo`14A4@08R8R000000000000
00000000003k:O00M`400000e03b4P00b8/G002ni@110;`0lQ800:Cc4P00/?l04P140;OcM`0hc_<0
Mooo0?oob02;5`00^o530038G@0H01P0o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000
C00000260P2D0@0004000<QM6000000000000000000100000>Bn01X0100100000000000000000>00
_AX0063c4P00K000200A000P000000000<R;01L0H01c@000e098001?L01UKP0000<000800000g?<0
4P100>i20004000001810000n00JG`00@cYL06Q_K@1UL640IfEL06MYIP1c04d0HGAX06E]H@1dJF<0
HD9Y06L^I`1YIP00g?<B0007PP3WM`000000000000008000003L0?<B000lm18004mR0?Mgc03c4P00
<0000000000300800000043^@P00kB40igND004200000P000000000060000@00dLjR00lH00000480
000000800000Ha40igN600:D0@0B0@0009G`00004P007`000000002N0P00004000000:QSG`00n1X0
G`3@00PF000C000002H0000000000000G?DB0002<`3]M`00000000PTG`00QP80U04B0040002El000
00000000P03d4P00OUSW07L8901O0000000000040000000000000000003RF>L0M`PT05l000000000
00@00030>P3XMd<0>UaX06m]I@1`HFL0IEaW06UVL`1LCF40M6QU06eQM01YHf40@VUW02iWJ@1V08H0
0Y@100000000RDX0mWM800DD001V000000P00000QP02U040>aM500260P2D0I@00@8001810000@aL0
A@2600:D0@30ma800080000000000000n1YO0007002:0A00mA8009XAk@1ge`@00GD7002:0@0N0`00
00000000J0035P000001003Hm@0B06@0BZ]g09810P00G?D04P0>05_WM`30RaL00000000000005000
8040000800000040000008Se4P00/bP0l7L0000D000800@001P10000IP000000IP0000260P2D0ML0
105e00000000208000000000001f0P00053e018000000000/?lB0014]`3cMlP0cO=g0?ooo`3o1HH0
@`2600:D0@040000=08000<0000e00D000070@<0000R1000@`lP0<`0000P02000000020080000000
:0000200000P00000@08000000001000a0h00<@>00000@0000000000001gMgL0EEEE0</0c03^k^h0
I@1V003;o@28R8P0oFD00?ooo`14A4@08R8R00000000000000000000003`:O/0005g0=@000004_80
5h_80>Fn002l044001;b01;cY03o/000A00B07Oc]`3ccSP0oomg0<Soo`005h/0@o6k05g8000H01P0
01;l0000IP2;b000QP0G006D0P0J_N0000400<P0000065d0001<00:600000I@0040001QMb0000000
0000000000000040_^@000@06P00004000000000003P000001Zm01;cH000K0004@08000P00000000
RlP006005`00@7<0B0;D071?0000KVD000<000000P3cg000@00B0012kP0000@00A800?P00000GaX0
G3Y306e_J01QL6D0G6EW06IYI`1=07<0J7AQ065]I@1SJG@0JD9Q06L^I`00IVT04_?L08870000MnL0
0000000000008000g000000Bl`0Bm3`0HTl00<agm`004_<0000`0000000200<0000004;^@00Qk@00
U7OW00020@000P00000001P000000@00X/kA000H3`120000000000000P0AH`00QWOW006D0P000A80
l9D0018000007`00000000:N00010000000005mSZ00Jn000d01O000F200001<002H0000000000000
4_EL03<20000Mnd0000005lT2002QP004P6D00000@00l9D00000080000004_@0ieQn02@8M`0005l0
000000040000000000000000003WF>8090Qg0000G`00000000@003[00013MnP0J5`j06E]K`1WHG00
IeaU07=VJ@1QCE`0IFQd07AQK@1QHfT0IfU206UW;P2606H00I@20000001:R@00B7Of000D1@0006H0
00P008H00001U080AALk00:6002D0I@0008100014P0G@`00QP15006D0P0Bml000080000000000000
Ga[h0007000@0HX001;e0>dAVP04egL01gD1006:00000ah0000006P000005P<00@000?GH001T0180
Mj]:0081TP3eG0003P0B07OWF`0GRl000000000000005000004P000800010000000001;eR00X/`00
07O`000D000400P00AP006H000000000001V00:6003G0I@0M@440000000220000000000000000WH0
mE0000004P0000004_n`0;M40038Mo<0Mo?=0?ooo`261Ol0QP13006D0P092@T00000000000000000
0000000000000000000000T000071`L71`L71`L71`L71`L71`L71`L71`L71`L000T0000000000000
0000000000000000000000001`002@0410@410@410@410@410@410@410@410@4100700T0000410@4
10@410@410@410@410@410@410@400L000T010@410@400000P4410@41040004410@410@01`002@04
10@410@02000000:100000D0000010@4100700T0000410@4100820011P0000D500030`0410@400L0
00T010@410@400P820001P051@070P0300@410@01`002@0410@4104020P8208000D01`L72`0210@4
100700T0000410@40@0820P8208000L71`L200@410@400L000T010@4104000P820P820071`L71`80
0@@410@01`002@0410@400D5000000000000000000000@@4100700T000040@0000002`X21`080P05
1@0000L000@400L000T010@000L71`L71`L000P820801@0000L000@01`002@0400<300L71`L70006
00P820P000030004100700T000000`<300L71`0000H600P820P00`<010@400L000T010800`<300L0
00D01PH600P800<30`<010@01`002@0410X0000000051@061PH600030`<30`<0100700T0000410@2
0000000000H61PH:00<30`0000@400L000T010@410@:00<30P000000000000000@@410@01`002@04
10@4100500830`<30`<300H6004410@4100700T0000410@1000700<30`<30`001PH010@410@400L0
00T010@410001`L00P<30`<020P01P0410@410@01`002@0410@400L:00000`<30P0020P000@410@4
100700T0000410@0000110400`80108000P010@410@400L000T010@410@410@4100300@410@10004
10@410@01`002@0410@410@410@4100410@410@40P@410@4100700T0000410@410@410@410@410@4
10@410@410@400L000T010@410@410@410@410@410@410@410@410@01`002@0410@410@410@410@4
10@410@410@410@410002@T000000000000000000000000000000000000000T9100002L1ool30000
00000140000<0000200000/0000@00005@0001D000090000400001D0000E00008@0000P0000:0000
40000000000000002@000100000O00007`000340000@10000@00000300400000MgMg05EEE@3<0</0
k^k^06H0I@3mb`00R8R8001Uo@3oool0A4A4028R8P0000000000000000000000nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0?8B002Tla800;3o0180A02glgL0><kc07Ooo`3oolP0RaL00;_a@`00b5d0
600H0?`B001V00000<R;01L0QP02U040h;dJ000100000<P0GAP004`00000QP80U04000100038GAP0
00000000000000000@00003T_P0J00@00@00000000000000003P0;dJ001Pla8006`000P04@008000
00000038R`0G0600Ld000=@2B000Cg00IFh00003000200000=cc0180@03^@P001000000B0@000?P0
6Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40M6US0652J@1W;VL0JFH00=cc4P001h80
igL000000000000002000000g03c4P00??@B001?HP3gMl`0la800300000000000`0200000010kT80
0>dQ0>MgU0010P0000800000000001P000400=7>XP0?6000001200000002000006<A0>MgQP02U040
4P40002El000018001l000000000WP8000010000002XHel00?PJ05l0d0085P004`00000V00000000
000005ce4P000S<0kGL00000000895l008H209@14P010000UO00000000000800m18007iHi`1g22@0
G`000000000010000000000000000000hUSW07L8901O0000000000040000`3X0j7M303YLJ01_KFD0
L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0JF=Q049YI`0^IfT0IP2600:D0@00000008U:0?IgB0055000
IP000008000008H00Y@103/GA@00QP80U06D0042000B0@0004<G04D0QP02U040`?LB000200000000
00000?PJG`001`00RP4@0?DB002J4Nd0MmL4005e1`00RP407P<00000000006P00aH000000@00f?D0
4P1T04Z[M`2B0@8005ce01803P1KigL0`8/G00000000000001@0020100002000000100000028mA80
0;<X0?1g000050002004000H0@0006H0000006H00000QP80U07G00@1M@00000000P2000000000000
MP80001@m@0B000000000;3o4P00A;L0lgO80<gcM`3oool0o`F604<0QP02U040<00000`000010000
=00000P0000E0000300000<0001A0000N0P00000000000005@0001D0000000000000000000000000
80000200001@0000:0@007P40000100000000200c00P0000800002P0000P00008000004020000000
00@00<@>00343P000040000000000000MgMg05EEE@3;0<`0k^k^06D0IP00bod0R8R80?eU003oool0
A4A4028R8P0000000000000000000000l2Wk0001M`3D000001;b01N;b03U_P00_011000BlP0Blj@0
ok0004@04P1glkL0llhh0?ooM`38ool001N;04?a^`1Mb000600H000Bo00006H0RlP008H05`01U080
6[gP00010038000001QM0000C002QP00006D0010000HGLP0000000000000000000010;kT000401X0
0001000000000000h000000J_@0Blf0006`0014020008000000008_8001P01L0041c04P2e01`C`00
06iU000300000080lm`004004P00@^h00004004B003h000005lJ05`j@`1]KfP0HG1U05aUI`1VJFL0
C@1c06QdH@1QKFD0HfUd06U2H@1W;VL006IY01;cg0221`0007OW00000000000002000=`000004_<0
4_@l069?003<MoL001;c0000<00000000P0300000012kT008Nd009Agi`000P4000800000000H0000
00400:;>d@0060l0@P000000000000804F<008Igi`01U080004B0?2E000B000001l000000002WP00
0@000000001OHjP06_P00=00G`005PP0000C000V00000000000001;eG00c0P0007O]0000001O90P0
0XH00181U00000400?2E00000020000001;d0>MHOP0T27L0001O0000000010000000000000000000
ieSR02@8M`0005l000000004000j`000@gOX06QL>P1UKFl0If5`06MLI@1cIVT0HDeL06EXM01dHFd0
HF=Y06MY@P1YIbh0QP1V006D0P000000BXT004QgmP0050D0001V0008002600000I@204DG>`02QP00
U06D00020@000A805d<008H0A@01U0804_O0000200000000000005lJn0001`00406:000Bm@3]4IX0
1=Mg00Me0@01RP0000<N0000001X000001H30040003ef000I00B07N[BP020I80mE`000h04P1gie/0
5h_000000000000001@00001800020000@000000000BmHP0:;<0001gl00050001008004H001V0000
00000000IP02QP00e`6D07D1100000000PP0000000000000009f0?E@00000180000001;o/02gA000
b7Oc07Occ@3oool0QPGo08H0@`01U0802@T900000000000000000000000000000000000000090000
1`L71`L71`L71`L71`L71`L71`L71`L71`L7000900000000000000000000000000000000000000L0
00T010@410@410@410@410@410@410@410@410@01`09000010@410@410@410@410@410@410@410@4
1007000900@410@41000008110@410@1000110@410@400L000T010@410@400P000002P@000050000
00@410@01`09000010@410@020P00@H000051@000`<010@41007000900@410@4100820P000H01@D0
1`800`0410@400L000T010@410@100P820P2000500L71`/00P@410@01`09000010@4104020P820P2
00071`L70P0410@41007000900@410@1000820P820P01`L71`L2004410@400L000T010@410051@00
0000000000000000004410@01`0900001040000000/:0PL020801@D0000700041007000900@40007
1`L71`L7000820P200D00007000400L000T010030`071`L71`001P0820P800000`0010@01`090000
00<30`071`L000061P0820P800<300@41007000900@200<30`07000500H61P0820030`<300@400L0
00T010@:000000001@D01PH61P000`<30`<300@01`09000010@40P00000000061PH62P030`<00004
1007000900@410@42P030`80000000000000004410@400L000T010@410@01@020`<30`<30`061P01
10@410@01`09000010@40@001`030`<30`<000H600@410@41007000900@410@000L700830`<300P8
00H010@410@400L000T010@410072P0000<30`8000P8000410@410@01`09000010@400000@@100<2
00@2000800@410@41007000900@410@410@410@00`0410@40@0010@410@400L000T010@410@410@4
10@010@410@4108410@410@01`09000010@410@410@410@410@410@410@410@41007000900@410@4
10@410@410@410@410@410@410@400L000T010@410@410@410@410@410@410@410@410@000T90000
0000000000000000000000000000000000092B80000<0000ooooobD0000<00001`00P2D0000<0000
0000P300000<00003`00P4/0000@0000000000D0000X000030000040000>000010<00;`0000@0000
000007MgM`1EEED0c03;0>k^kP1V06D0oL/008R8R000IOd0oooo04A4A00R8R80nbW`07L100000=@0
lQ800<R;5`00_^D0@@2l0:Cc4P00/?l04P140;OcM`0hc_<0Mooo0?oob02;5`00^o530038G@0H01P0
o18006H00000b8/05`2600:D0@3P_AX000400000b01M6000C00000260P2D0@0004000<QM60010000
0>Bn01X010000>00_AX0063c4P00K000200A000P000G0600Ld000=@2B000Cg00IFh0000300020000
0=cc0180@03^@P001000000B0@000?P06Ul004<jG01XKfd0IG1Q06MUG01WJFH0L`1=065dJ01UKF40
M6US0652J@1W;VL0JFH00=cc4P001h80igL00000g03c4P00??@B001?HP3gMl`0<00000<00P10kT80
0>dQ0>MgU0010P0000800000603AcZ803aP00000@P00Ha40igN601810000UO00000B000O0000WP80
00010:QSG`00n1X0G`3@00PF000C000002H005ce4P000S<0kGL000PTG`2D0A80UO000000P03d4P00
OUSW07L8901O000000@00>9Hi`00`3X0j7M303YLJ01_KFD0L65W06ELI`1YIW<0G4eQ07AXI@1]HG@0
JF=Q049YI`0^IfT0IP260029BP3fMdP01A@00008000008H0>aM509@1U000@aL0A@260<3g4P3h6Ul0
00L008X1403e4P00VQ7]07OG1001M@L008X101h3000006P00aH0003Hm@0B06@0BZ]g09810P00G?D0
4P0>05_WM`30RaL001@002010028mA800;<X0?1g000800@001P10000IP2D0ML0105e00080P1f0P00
053e0180002`oa8004Bg0?=gb03=lgL0o`F604<0QP040`00
\>"], "Graphics",
    ImageSize->{21, 21}],
  "  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True,
  FontSize->18,
  CellTags->"Section 4.2"],

Cell[TextData[{
  "\tAn impetus for studying complex analysis is the comparison of properties \
of real numbers and functions with their complex counterparts.  In this \
section we take a look at Newton's method for finding solutions to the \
equation  ",
  Cell[BoxData[
      \(f \((x)\) = 0\)]],
  ".  We then examine the more general topic of iteration.\n\n\tRecall from \
calculus that ",
  ButtonBox["Newtons Method",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/NewtonsMethod.html"], None},
    ButtonStyle->"Hyperlink"],
  " method proceeds by starting with a function  f(x)  and an initial \"guess\
\"  ",
  Cell[BoxData[
      \(x\_0\)]],
  "  as a solution to  ",
  Cell[BoxData[
      \(f \((x)\) = 0\)]],
  ".  We then generate a new guess  ",
  Cell[BoxData[
      \(x\_1\)]],
  "  by the computation  ",
  Cell[BoxData[
      \(x\_1 = x\_0 - \(f \((x\_0)\)\)\/\(f' \((x\_0)\)\)\)]],
  ".  Using  ",
  Cell[BoxData[
      \(x\_1\)]],
  " in place of  ",
  Cell[BoxData[
      \(x\_0\)]],
  ",  this process is repeated, giving us  ",
  Cell[BoxData[
      \(x\_2 = x\_1 - \(f \((x\_1)\)\)\/\(f' \((x\_1)\)\)\)]],
  ".  Thus we obtain a sequence of points  ",
  Cell[BoxData[
      \({x\_k}\)]],
  ", where  ",
  Cell[BoxData[
      \(x\_\(k + 1\) = x\_k - \(f \((x\_k)\)\)\/\(f' \((x\_k)\)\)\)]],
  ".  The points  ",
  Cell[BoxData[
      \({x\_k}\_\(k = 0\)\%\[Infinity]\)]],
  "  are called the ",
  StyleBox["iterates",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " of  ",
  Cell[BoxData[
      \(x\_0\)]],
  ".  For functions defined on the real numbers, this method gives remarkably \
good results so that the sequence  ",
  Cell[BoxData[
      \({x\_k}\)]],
  "  often converges to a solution of  ",
  Cell[BoxData[
      \(f \((x)\) = 0\)]],
  "  rather quickly.  In the late 1800's the british mathematician ",
  ButtonBox["Arthur Cayley",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Cayley.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " investigated the question as to whether Newton's method can be applied to \
complex functions.  He wrote a paper giving an analysis for how this method \
works for quadratic polynomials and indicated his intention to publish a \
subsequent paper for cubic polynomials.  Unfortunately, Cayley died before \
producing this paper.  As you will see, The extension of ",
  ButtonBox["Newton's",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Newton.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " method to the complex domain and the more general question of iteration \
are quite complicated."
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.7,  Page 134.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Trace out the next five iterates of Newton's method given an initial \
guess of  ",
  Cell[BoxData[
      \(z\_0 = 1\/4 + \[ImaginaryI]\/4\)]],
  "  as a solution to the equation  ",
  Cell[BoxData[
      \(f[z] = 0\)]],
  ",  where  ",
  Cell[BoxData[
      \(f[z] = z\^2 + 1\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.7.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^2 + 1\)]],
  "  and find the next five iterates."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i, k, K, list, set];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_]\  = \ z\^2\  + \ 1\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(K = Table[i, {i, 0, 5}];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = Table[0, {6}];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_\(\(\[LeftDoubleBracket]\)\(1\)\(\[RightDoubleBracket]\)\) = 
        N[1\/4 + \[ImaginaryI]\/4];\)\ \), "\[IndentingNewLine]", 
    \(\(g[z_] = z - f[z]\/\(f'\)[z];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\n", 
    \(\(Print["\<The formula for iteration is\>"];\)\ \), \
"\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_\\\"\<k+1\>\\\"\) = \!\(z\_k\) - \!\(\*\\\"\\\\\\\
\"\<f[\\!\\(z\\_k\\)]\>\\\\\\\"\\\"\/\*\\\"\\\\\\\"\<f'[\\!\\(z\\_k\\)]\>\\\\\
\\\"\\\"\) = \>\"", 
        g[\*"\"\<\!\(z\_k\)\>\""]];\)\ \[IndentingNewLine]\)}], "Input"],

Cell[TextData[{
  "\nNow compute the next five iterates  ",
  Cell[BoxData[
      \(z\_k\)]],
  "  and the corresponding values of  ",
  Cell[BoxData[
      \(f[z\_k]\)]],
  "."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(For[k = 0, 
        k \[LessEqual] 
          4, \(k++\), \[IndentingNewLine]\(Z\_\(\(\[LeftDoubleBracket]\)\(k + \
2\)\(\[RightDoubleBracket]\)\) = 
            g[Z\_\(\(\[LeftDoubleBracket]\)\(k + 1\)\(\[RightDoubleBracket]\)\
\)];\)\ \ ];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Transpose[{K, Z, 
              f[Z]}], \[IndentingNewLine]TableHeadings \[Rule] {None, \
{"\<k\>", \*"\"\<\!\(z\_k\)\>\"", \*"\"\<f[\!\(z\_k\)]\>\""}}]];\)\ \
\[IndentingNewLine]\)}], "Input"],

Cell[TextData[{
  "\nPlot the iterates  ",
  Cell[BoxData[
      \(z\_k\)]],
  "  and observe that they are converging to  ",
  Cell[BoxData[
      \(z = \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(set\  = \ \ ReplaceAll[Z, 
          xx_Real \[Rule] {xx, 0}];\)\ \), "\n", 
    \(\(list\  = \ \ ReplaceAll[set, 
          Complex[xx_, yy_] \[Rule] {xx, yy}];\)\ \), "\[IndentingNewLine]", 
    \(\(ListPlot[list, PlotRange \[Rule] {{\(-0.9\), 0.5}, {0.0, 1.2}}, 
        Prolog \[Rule] {PointSize[0.02], 
            Magenta}, \[IndentingNewLine]AspectRatio \[Rule] 1.2\/1.4, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}, \[IndentingNewLine]Ticks \
\[Rule] {Range[\(-1\), 1, 0.2], 
            Range[0, 1.2, 0.2]}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[
        TableForm[
          Transpose[{K, 
              Z}], \[IndentingNewLine]TableHeadings \[Rule] {None, {"\<k\>", \
\*"\"\<\!\(z\_k\)\>\""}}]];\)\ \[IndentingNewLine]\)}], "Input"],

Cell[TextData[{
  "\nNotice that the points  ",
  Cell[BoxData[
      \(z\_4\ \ and\ \ z\_5\)]],
  "  are co close together that they appear to coincide and that the value \
for  ",
  Cell[BoxData[
      \(\(\(\ \)\(z\_5\)\)\)]],
  "  agrees to six decimal places with the actual solution  ",
  Cell[BoxData[
      \(z = \[ImaginaryI]\)]],
  ".  "
}], "Text"]
}, Closed]],

Cell["\<\

\tThe complex version of Newton's method appears also to work quite well.  \
You may recall, however, that with functions defined on the reals, it is not \
the case that every initial guess produces a sequence that converges to the \
solution.  Example 4.21 shows that the same is true in the complex \
case.\
\>", "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.8,  Page135.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that Newton's method fails for the function  ",
  Cell[BoxData[
      \(f[z] = z\^2 + 1\)]],
  "  if our initial guess is a real number."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.8.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "\tFrom Example 4.20 we know that given any guess  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  as a solution of  ",
  Cell[BoxData[
      \(z\^2 + 1 = 0\)]],
  ", the next guess at a solution is ",
  Cell[BoxData[
      \(z\_1 = \(z\_0 - 
            f[z\_0]\/\(f'\)[z\_0] = \(z\_0\%2\  - \ 1\)\/\(2  z\_0\)\)\)]],
  ".  Let  ",
  Cell[BoxData[
      \({z\_k}\)]],
  "  be the sequence of iterations produced by the initial seed  ",
  Cell[BoxData[
      \(z\_0\)]],
  ".  If for any k,  ",
  Cell[BoxData[
      \(z\_k = 0\)]],
  ", the iteration terminates with an undefined result.  If all of the terms \
of the infinite sequence  ",
  Cell[BoxData[
      \({z\_k}\)]],
  "  are defined, an easy induction argument shows that all the terms in the \
sequence will be real valued.  Since the solutions of  ",
  Cell[BoxData[
      \(z\^2 + 1 = 0\)]],
  "  are  ",
  Cell[BoxData[
      \(z = \(\[PlusMinus]\[ImaginaryI]\)\)]],
  ", the sequence  ",
  Cell[BoxData[
      \({z\_k}\)]],
  "  cannot possibly converge to either solution.  In the exercises we ask \
you to explore in detail what happens when  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is in the upper or lower half plane."
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Extra Example for Page135.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Investigate Newton's method for finding the roots of  ",
  Cell[BoxData[
      \(f[z] = z\^3 + 1\)]],
  ".\nGiven the initial seed  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  determine if the sequence  ",
  Cell[BoxData[
      \({z\_k}\)]],
  "  converges to one of the roots  ",
  Cell[BoxData[
      \(z = \(-1\), 1\/2 + \(\[ImaginaryI]\ \@3\)\/2, 
      1\/2 - \(\[ImaginaryI]\ \@3\)\/2\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Extra Solution for Page 135.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^3 + 1\)]],
  "  and find its roots."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = z\^3 + 1;\)\ \), "\[IndentingNewLine]", 
    \(\(solset = Solve[f[z] \[Equal] 0, z];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_1 = 
        ComplexExpand[
          solset\_\(\(\[LeftDoubleBracket]\)\(1, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          TargetFunctions \[Rule] {Im, Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_2 = 
        ComplexExpand[
          solset\_\(\(\[LeftDoubleBracket]\)\(2, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          TargetFunctions \[Rule] {Im, Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_3 = 
        ComplexExpand[
          solset\_\(\(\[LeftDoubleBracket]\)\(3, 1, \
2\)\(\[RightDoubleBracket]\)\), 
          TargetFunctions \[Rule] {Im, Re}];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The roots are\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_1\) = \>\"", 
        Z\_1];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_2\) = \>\"", 
        Z\_2];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(z\_3\) = \>\"", 
        Z\_3];\)\ \[IndentingNewLine]\)}], "Input"],

Cell[TextData[{
  "\nWe color each point ",
  Cell[BoxData[
      \(z\_0\)]],
  "  in the rectangle  ",
  Cell[BoxData[
      \(R = {z = 
            x + \(\[ImaginaryI]y : \(-2\) \[LessEqual] x \[LessEqual] 
                  2\), \(-2\) \[LessEqual] x \[LessEqual] 2}\)]],
  " in the following fashion.  Color the point yellow, blue, or red, if the \
sequence of iterations produced by the seed  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  converges to ",
  Cell[BoxData[
      \(\(-1\), 1\/2 + \(\[ImaginaryI]\ \@3\)\/2, 
      1\/2 - \(\[ImaginaryI]\ \@3\)\/2\)]],
  ", respectively.  The iteration formula is "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(g[z_] = 
        Together[z - f[z]\/\(f'\)[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<g[z] = \>", g[z]];\)\ \[IndentingNewLine]\)}], "Input"],

Cell[TextData[{
  "\nThe formulas for  f[z] and  g[z]  and approximations to the roots ",
  Cell[BoxData[
      \(z = \(-1\), 1\/2 + \(\[ImaginaryI]\ \@3\)\/2, 
      and\ 1\/2 - \(\[ImaginaryI]\ \@3\)\/2\)]],
  " are used in the function  newton[x,y]  to make the density plot."
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(newton = \n
        Compile[{x, y}, \[IndentingNewLine]Module[{z, ct = 0}, 
            z = x + \[ImaginaryI]\ y; \ \[IndentingNewLine]While[
              Abs[Evaluate[z\^3 + 1]] > 0.001\  && \ 
                ct \[LessEqual] 
                  50, \[IndentingNewLine]z = \(\(-1\) + 2\ z\^3\)\/\(3\ \
z\^2\); \ \(++ct\)]; \ \[IndentingNewLine]Which[\[IndentingNewLine]Abs[
                  z - \((\(-1\))\)] < 0.1, 
              0.15, \[IndentingNewLine]Abs[
                  z - \((0.5\[InvisibleSpace] + 0.866\ \[ImaginaryI])\)] < 
                0.1, 0.5, \[IndentingNewLine]Abs[
                  z - \((0.5\[InvisibleSpace] - 0.866\ \[ImaginaryI])\)] < 
                0.1, 0.9]]\ ];\)\(\ \)\(\[IndentingNewLine]\)\)\)], "Input"],

Cell[TextData[{
  "\nMake a plot showing the initial seeds  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  and the nature of the sequence ",
  Cell[BoxData[
      \({z\_k}\)]],
  "  that is produced by it."
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(DensityPlot[
        newton[x, y], \[IndentingNewLine]{x, \(-2\), 2. }, \ {y, \(-2\), 
          2}, \[IndentingNewLine]PlotPoints \[Rule] 100, Mesh \[Rule] False, 
        AspectRatio \[Rule] 1, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<Yellow points converge to  -1.\>"];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Blue points converge to  \!\(1\/2\)+\!\(\*\\\"\\\\\\\"\<\
\[ImaginaryI]\\!\\(\\@3\\)\>\\\\\\\"\\\"\/2\).\>\""];\)\ \), "\
\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Red  points converge to  \!\(1\/2\)-\!\(\*\\\"\\\\\\\"\<\
\[ImaginaryI]\\!\\(\\@3\\)\>\\\\\\\"\\\"\/2\).\>\""];\)\ \
\[IndentingNewLine]\)}], "Input"]
}, Closed]],

Cell[TextData[{
  "\n\tIn 1918 the French mathematicians ",
  ButtonBox["Gaston Julia",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Julia.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["Pierre Fatou",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fatou.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  " noticed the fractal phenomenon when exploring iterations of functions not \
necessarily connected with Newton's method.  Beginning with a function  f(z)  \
and a point  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  they computed the iterates  ",
  Cell[BoxData[
      \(z\_1 = f \((z\_0)\)\)]],
  ", ",
  Cell[BoxData[
      \(z\_2 = f \((z\_1)\)\)]],
  ", ... , ",
  Cell[BoxData[
      \(z\_\(k + 1\) = f \((z\_k)\)\)]],
  ", and investigated properties of the sequences  ",
  Cell[BoxData[
      \({z\_k}\)]],
  ".  Their findings did not receive a great deal of attention, largely \
because computer graphics were not available at this time.  With the recent \
proliferation of computers, it is not surprising that these investigations \
were revived in the 1980's.  Detailed studies of Newton's method and the more \
general topic of iteration were undertaken by a host of mathematicians \
including Curry, Douady, Garnett, Hubbard, ",
  ButtonBox["Mandelbrot",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mandelbrot.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ", ",
  ButtonBox["Milnor",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Milnor.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " and Sullivan.  We now turn our attention to some of their results by \
focusing on the iterates produced by quadratics of the form   ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.9,  Page 137.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Given  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  ",  analyze all possible iterations for the function  ",
  Cell[BoxData[
      \(\(f\_0\) \((z)\) = z\^2 + 0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.9.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "In the exercises we will ask you to verify that if  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "  the sequence will converge to  0,  i",
  "f  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\(\(>\)\(\ \)\(1\)\)\)\)]],
  "  the sequence will be unbounded, and if",
  "  ",
  Cell[BoxData[
      \(\(\(|\)\(z\_0\)\(|\)\) = \ 1\)]],
  "  the sequence will either oscillate chaotically around the unit circle or \
converge to  1."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False]
}, Closed]],

Cell[TextData[{
  "\n\tGiven the function  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\) = z\^2 + c\)]],
  ",  and an initial seed  ",
  Cell[BoxData[
      \(z\_0\)]],
  ",  the set of iterates given by  ",
  Cell[BoxData[
      \(z\_1 = \(f\_c\) \((z\_0)\)\)]],
  ", ",
  Cell[BoxData[
      \(z\_2 = \(f\_c\) \((z\_1)\)\)]],
  ", etc., are also called the ",
  StyleBox["orbits",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  " of  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  generated by  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  ".  Let  ",
  Cell[BoxData[
      \(K\_c\)]],
  "  denote the set of points with bounded orbits for  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  ".  Example 4.9 shows that  ",
  Cell[BoxData[
      \(K\_0\)]],
  "  is the closed unit disk ",
  Cell[BoxData[
      \(\(\(D\_1\)\&_\) \((0)\)\)]],
  ".  The boundary of  ",
  Cell[BoxData[
      \(K\_c\)]],
  "  is known as the ",
  ButtonBox["Julia Set",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/JuliaSet.html"], None},
    ButtonStyle->"Hyperlink"],
  " for the function  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  ".  The Julia set for  ",
  Cell[BoxData[
      \(\(f\_0\) \((z)\)\)]],
  "  is the unit circle  ",
  Cell[BoxData[
      \(\(C\_1\) \((0)\)\)]],
  ".  It turns out that  ",
  Cell[BoxData[
      \(K\_c\)]],
  "  is a nice simple set only when  ",
  Cell[BoxData[
      \(c = \(0\ \ or\ \ c = \(-2\)\)\)]],
  ".  Otherwise,   ",
  Cell[BoxData[
      \(K\_c\)]],
  "  is fractal.  \n\n\tJulia and Fatou independently discovered a simple \
criterion that can be used to tell when the Julia set for  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  "  is connected or disconnected.  We state their result, but omit the \
proof, as it is beyond the scope of this text."
}], "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 4.8, Page 138.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The boundary of  ",
  Cell[BoxData[
      \(K\_c\)]],
  "  is connected if and only if  ",
  Cell[BoxData[
      \(0  \[Epsilon]\ K\_c\)]],
  ".  In other words, the Julia set for  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  "  is connected if and only if the orbits of  0  are bounded."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.10,  Page 138.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that the Julia set for  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\) = z\^2 + \[ImaginaryI]\)]],
  "  is connected."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.10.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "We apply Theorem 4.8 and compute the orbits of  0  for  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\) = z\^2 + \[ImaginaryI]\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, i];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = z\^2 + \[ImaginaryI];\)\ \), "\[IndentingNewLine]", 
    \(\(Z = NestList[f, 0, 7];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<f[z] = \>", f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(For[i = 0, 
        i \[LessEqual] 
          6, \(i++\), \[IndentingNewLine]\(Print["\<f[\>", 
            Z\_\(\(\[LeftDoubleBracket]\)\(i + 1\)\(\[RightDoubleBracket]\)\)\
\ , "\<] = \>", 
            Z\_\(\(\[LeftDoubleBracket]\)\(i + \
2\)\(\[RightDoubleBracket]\)\)];\)\ \ ];\)\ \[IndentingNewLine]\)}], "Input"],

Cell[TextData[{
  "\nThus, the orbits of  0  is the sequence  ",
  Cell[BoxData[
      \({0, \[ImaginaryI], \(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\), \(-1\) \
+ \[ImaginaryI], \(-\[ImaginaryI]\), \(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\
\),  ... }\)]],
  "  which is clearly a bounded sequence.  Thus, by Theorem 4.14, the Julia \
set for  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\)\)]],
  "  is connected."
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Extra Example for  Page 138.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Plot the Julia set."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Extra Solution for Page 138.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Here is the subroutine from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  Journal."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(juliaC\  = \n
        Compile[{x, y, lim, cx, cy}, \[IndentingNewLine]Module[{z, ct = 0}, 
            z = x + \[ImaginaryI]\ y; \ \[IndentingNewLine]While[
              Abs[z] < 2.0\  && \ ct \[LessEqual] lim, \[IndentingNewLine]z = 
                z\^2 + \((cx + \[ImaginaryI]\ cy)\); \ \(++ct\)]; \ 
            ct]\ ];\)\(\ \)\(\[IndentingNewLine]\)\)\)], "Input"],

Cell[TextData[{
  "Here is the Julia set generated by the value  c = -1.25.  This is a fuzzy \
picture of Color Plate 4.  Increase the number of PlotPoints to get a sharper \
picture.  Also, it will increase the computing time.  It takes quite a bit of \
time with  ",
  Cell[BoxData[
      \(PlotPoints \[Rule] 200\)]],
  ".  Things start to look better with  ",
  Cell[BoxData[
      \(PlotPoints \[Rule] 500\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(DensityPlot[\(-juliaC[x, y, 50, \(-1.25\), 
            0]\), \[IndentingNewLine]{x, \(-1.5\), 1.5}, \ {y, \(-1.0\), 
          1.0}, \[IndentingNewLine]PlotPoints \[Rule] 200, 
        Mesh \[Rule] False, 
        AspectRatio \[Rule] 2\/3, \[IndentingNewLine]ColorFunction \[Rule] 
          Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Julia set generated by the value c = -1.25\>"];\)\ \
\[IndentingNewLine]\)}], "Input",
  AspectRatioFixed->True]
}, Closed]],

Cell[TextData[{
  "\n\tIn 1980, the Polish born mathematician ",
  ButtonBox["Benoit Mandelbrot",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Mandelbrot.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " used computer graphics to study the following set:  \n\n",
  Cell[BoxData[
      \(M = \({c : \ 
              the\ Julia\ set\ for\ \(f\_c\) \((z)\)\ is\ connected}\n\ \  = \
{c : \ the\ orbits\ of\ \ 0\ \ determined\ by\ \(f\_c\) \((z)\)\ are\ \
bounded}\)\)]],
  "  \n\nThe set  M  has come to be known as the ",
  ButtonBox["Mandelbrot Set",
    ButtonData:>{
      URL[ "http://mathworld.wolfram.com/MandelbrotSet.html"], None},
    ButtonStyle->"Hyperlink"],
  ".  The remainder of this section looks at some of the properties of this \
amazing set."
}], "Text"],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.11,  Page 139.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Show that ",
  Cell[BoxData[
      \({c : \(\(|\)\(z\)\(|\)\(\(\[LessEqual]\)\(1\/4\)\)\)}\)]],
  " is a subset of the Mandelbrot set  M."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["Solution 4.11.",
    FontColor->RGBColor[1, 0, 1]],
  "  See page 139 in the text."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell["\<\

\tThere are other methods for determining which points belong to  M.  To see \
what they are, we need some additional vocabulary.\
\>", "Text"],

Cell[TextData[{
  StyleBox["\nDefinition 4.5 (Fixed Point), Page 139.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The point  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is a fixed point for the function  f  if  ",
  Cell[BoxData[
      \(f \((z\_0)\) = z\_0\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nDefinition 4.6 (Attracting Point), Page 139.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The point  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is an attracting point for the function  f  if  ",
  Cell[BoxData[
      \(\(\(|\)\(f' \((z\_0)\)\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nTheorem 4.9, Page 139.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  Suppose ",
  Cell[BoxData[
      \(z\_0\)]],
  "  is an attracting fixed point for the function  f.  Then there is a disk  \
",
  Cell[BoxData[
      \(\(D\_r\) \((z\_0)\)\)]],
  "  about  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  such that the iterates of all the points in ",
  Cell[BoxData[
      \(\(D\_r\) \((z\_0)\)\)]],
  "  are dawn toward the point  ",
  Cell[BoxData[
      \(z\_0\)]],
  "  in the sense that if  ",
  Cell[BoxData[
      \(z \[Element] \(D\_r\%*\) \((z\_0)\)\)]],
  ", then  ",
  Cell[BoxData[
      \(\(\(|\)\(f \((z)\) - 
          z\_0\)\(|\)\(\(<\)\(\(|\)\(z - z\_0\)\(|\)\)\)\)\)]],
  "."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 4.15,  see text Page 139.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n\tIn 1905, ",
  ButtonBox["Pierre Fatou",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Fatou.html"]\
, None},
    ButtonStyle->"Hyperlink"],
  " showed that if the function  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  "  has attracting fixed points, the orbits of  0  determined by  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  "  must converge to one of them.  Since a convergent sequence is bounded, \
this implies that  c  must belong to  M.  In the exercises we ask you to show \
that the main cardioid-shaped body of  M is composed of those points  c  for \
which  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  "  has attracting fixed points.  You will find that Theorem 4.16 is a \
useful characterization of them."
}], "Text"],

Cell[TextData[{
  StyleBox["\nTheorem 4.10, Page 140.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  The points  c  for which  ",
  Cell[BoxData[
      \(\(f\_c\) \((z)\)\)]],
  "  has attracting fixed points satisfy  ",
  Cell[BoxData[
      \(\(\(|\)\(1 + \((1 - 4  c)\)\^\(1/2\)\)\(|\)\(\(<\)\(\ \
\)\(1\)\)\)\)]],
  "  or  ",
  Cell[BoxData[
      \(\(\(|\)\(1 - \((1 - 4  c)\)\^\(1/2\)\)\(|\)\(\(<\)\(\ \
\)\(1\)\)\)\)]],
  ",  where the square root is the principal square root function."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[StyleBox["Proof of Theorem 4.16,  see text Page 140.",
  FontWeight->"Bold",
  FontColor->RGBColor[0, 1, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nDefinition 4.7 (n-Cycle), Page 140.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  An n-cycle for a function  f  is a set  ",
  Cell[BoxData[
      \({z\_0, z\_1,  ... , z\_\(n - 1\)}\)]],
  "  of  n  complex numbers such that  ",
  Cell[BoxData[
      \(z\_k = f \((z\_\(k - 1\))\)\)]],
  "  for  ",
  Cell[BoxData[
      \(k = 1, 2,  ... , n - 1\)]],
  ",  and  ",
  Cell[BoxData[
      \(f \((z\_\(n - 1\))\) = z\_0\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  StyleBox["\nDefinition 4.8, Page 141.",
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0, 1]],
  "  An n-cycle  ",
  Cell[BoxData[
      \({z\_0, z\_1,  ... , z\_\(n - 1\)}\)]],
  "  for a function  f   is said to be attracting if  ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_n\%'\) \((z\_0)\)\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ",  where  ",
  Cell[BoxData[
      \(g\_n\)]],
  "  is the composition of  f  with itself  n  times.  \nFor example, if n = \
2, then ",
  Cell[BoxData[
      \(\(g\_2\) \((z)\)\  = \ f \((f \((z)\))\)\)]],
  ". "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[TextData[{
  "\n",
  StyleBox["Example 4.12,  Page 141.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  "  Example 4.23 shows that  ",
  Cell[BoxData[
      \({\(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\)}\)]],
  "  is a 2-cycle for the function  ",
  Cell[BoxData[
      \(\(f\_\[ImaginaryI]\) \((z)\) = z\^2 + \[ImaginaryI]\)]],
  ".  Show that it is not an attracting 2-cycle."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Solution 4.12.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "Enter the function  ",
  Cell[BoxData[
      \(f[z] = z\^2 + \[ImaginaryI]\)]],
  "  and point  ",
  Cell[BoxData[
      \(z\_0 = \(-1\) + \[ImaginaryI]\)]],
  "  and determine if  ",
  Cell[BoxData[
      \(\(\(|\)\(\(g\_n\%'\) \((z\_0)\)\)\(|\)\(\(<\)\(\ \)\(1\)\)\)\)]],
  ".  "
}], "Text"],

Cell[BoxData[{
    \(\[IndentingNewLine]\(Remove[z, Z];\)\ \), "\[IndentingNewLine]", 
    \(\(Clear[f, g2];\)\ \), "\[IndentingNewLine]", 
    \(\(f[z_] = z\^2 + \[ImaginaryI];\)\ \), "\n", 
    \(\(g2[z_] = 
        Apart[ComplexExpand[f[f[z]]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Z\_0 = \(-1\) + \[ImaginaryI];\)\ \), "\n", 
    \(\(Print[\*"\"\<\!\(f\_\[ImaginaryI]\)[z] = \>\"", 
        f[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(g\_2\)[z] = \>\"", 
        g2[z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\(g\_2\%'\)\)[z] = \>\"", \(g2'\)[
          z]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<\>"];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<\!\(\(g\_2\%'\)\)[\>\"", 
        Z\_0, "\<] = \>", \(g2'\)[Z\_0]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<|\!\(\(g\_2\%'\)\)[\>\"", Z\_0, "\<]| = \>", 
        Abs[\(g2'\)[Z\_0]]];\)\ \), "\[IndentingNewLine]", 
    \(\(Print[\*"\"\<Is  |\!\(\(g\_2\%'\)\)[\>\"", Z\_0, "\<]| > 1 ?  \>", 
        Abs[\(g2'\)[Z\_0]] > 1];\)\ \[IndentingNewLine]\)}], "Input"],

Cell[TextData[{
  "\nTherefore,  ",
  Cell[BoxData[
      \({\(-1\) + \[ImaginaryI], \(-\[ImaginaryI]\)}\)]],
  "  is not an attracting 2-cycle."
}], "Text"]
}, Closed]],

Cell[TextData[{
  "\n",
  StyleBox["Extra Example for  Page 141.",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  " Plot the Mandelbrot set."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Extra Solution for Page 141.",
  FontWeight->"Bold",
  FontColor->RGBColor[1, 0, 1]]], "Text",
  Evaluatable->False,
  AspectRatioFixed->False],

Cell[TextData[{
  "This modification of the  juliaC  code can be used to plot the Mandelbrot \
set.\n\nHere is the subroutine from the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "  Journal."
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(mandelbrotC = 
        Compile[{x, y, lim}, \[IndentingNewLine]Module[{z, ct = 0}, 
            z = x + \[ImaginaryI]\ y; \ \[IndentingNewLine]While[
              Abs[z] < 2.0\  && \ ct \[LessEqual] lim, \[IndentingNewLine]z = 
                z\^2 + \((x + \[ImaginaryI]\ y)\); \ \(++ct\)]; \ 
            ct]\ ];\)\(\ \)\(\[IndentingNewLine]\)\)\)], "Input"],

Cell[TextData[{
  "This is a fuzzy picture of Color Plate 6. Increase the number of \
PlotPoints to get a sharper picture.  Also, it will increase the computing \
time.  It takes quite a bit of time with  ",
  Cell[BoxData[
      \(PlotPoints \[Rule] 200\)]],
  ".  Things start to look better with  ",
  Cell[BoxData[
      \(PlotPoints \[Rule] 500\)]],
  ".  "
}], "Text",
  Evaluatable->False,
  AspectRatioFixed->True],

Cell[BoxData[{
    \(\[IndentingNewLine]\(DensityPlot[\(-mandelbrotC[x, y, 
            50]\), \[IndentingNewLine]{x, \(-2.0\), 0.55}, \ {y, \(-1.15\), 
          1.15}, \[IndentingNewLine]PlotPoints \[Rule] 200, \ 
        Mesh \[Rule] False, \[IndentingNewLine]Frame \[Rule] False, 
        ColorFunction \[Rule] Hue];\)\ \), "\[IndentingNewLine]", 
    \(\(Print["\<The Mandelbrot set.\>"];\)\ \[IndentingNewLine]\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Library Research Experience for Undergraduates",
  FontSize->16,
  FontWeight->"Bold",
  FontColor->RGBColor[0.500008, 0, 0.996109]]], "Text"],

Cell[TextData[{
  StyleBox["Project I. Write a report on how complex analysis is used in the \
study of dynamical systems.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  "\n\n",
  StyleBox["1.",
    FontWeight->"Bold"],
  " Devaney, Robert L., (1986), An Introduction To Chaotic Dynamical Systems, \
Menlo Park, CA., Benjamin/Cummings.\n\n",
  StyleBox["2.",
    FontWeight->"Bold"],
  " Devaney, Robert L., (1990), Chaos, Fractals and Dynamics: Computer \
Experiments in Math., N.Y., Addison-Wesley Pub. Co."
}], "Text"],

Cell[TextData[{
  StyleBox["Project II. Write a report on how complex analysis is used in the \
study of fractals.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  "\n\n",
  StyleBox["1.",
    FontWeight->"Bold"],
  " Bannon, Thomas J., (1991), ''Fractals and Transformations,'' Math. \
Teach., V. 81, No. 3, pp. 178-185.\n\n",
  StyleBox["2.",
    FontWeight->"Bold"],
  " Barcellos, Anthony, (1984), ''The Fractal Geometry of Mandelbrot,'' T. Y. \
C. Math. J., V. 15, No. 2, pp. 98-114.\n\n",
  StyleBox["3.",
    FontWeight->"Bold"],
  " Gilbert, William J., (1982), ''Fractal Geometry Derived from Complex \
Bases,'' Math. Intell., V. 4, pp. 78-86.\n\n",
  StyleBox["4.",
    FontWeight->"Bold"],
  " Goffinet, Daniel, (1991), ''Number Systems With a Complex Base: a Fractal \
Tool for Teaching Topology,'', Am. Math. M., V. 98, No. 3, pp. 249-255.\n\n",
  StyleBox["5.",
    FontWeight->"Bold"],
  " Mandelbrot, Benoit B., (1983), ''Self-Inverse Fractals Osculated by \
Sigma-Discs and the Limit Sets of Inversion Groups,'' Math. Intell., V. 5, \
No. 2, pp. 9-17.\n\n",
  StyleBox["6.",
    FontWeight->"Bold"],
  " Nievergelt, Yves, (1991), ''Fractals Illustrate the Mathematical Way of \
Thinking,'' Coll. Math. J., V. 22, No. 1, pp. 60-64.\n\n",
  StyleBox["7.",
    FontWeight->"Bold"],
  " Straffin, Philip D., (1991), ''Newton's Method and Fractal Patterns,'' \
UMAP J., V. 12, No. 2, pp. 147-164, and UMAP, Module 716, pp. 1-18, COMAP, \
Inc. Lexington, MA 02420 USA. ",
  StyleBox[ButtonBox["COMAP",
    ButtonData:>{
      URL[ "http://www.comap.com/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   \n\n",
  StyleBox["8.",
    FontWeight->"Bold"],
  " Zobitz, Jennifer, (1987), ''Fractals: Math. Monsters,'' Pi Mu Epsilon J., \
V. 8, No. 7, pp. 425-440."
}], "Text"],

Cell[TextData[{
  StyleBox["Project III. Write a report on how complex analysis is used the \
study Julia sets.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  "\n\n",
  StyleBox["1.",
    FontWeight->"Bold"],
  " Peitgen, H. O. and D. Saupe and F. V. Haeseler, (1984), ''Cayley's \
Problem and Julia Sets,'' Math. Intell., V. 6, No. 2, pp. 11-20.\n\n",
  StyleBox["2.",
    FontWeight->"Bold"],
  " Vrscay, Edward R., ''Julia Sets and Mandelbrot-Like Sets Associated With \
Higher Order Schroder Rational Iteration Functions: A Computer Assisted \
Study,'' Math. of Computation, Vol. 46, No. 173. (Jan., 1986), pp. 151-169., \
",
  StyleBox[ButtonBox["Jstor.",
    ButtonData:>{
      URL[ "http://www.jstor.org/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   "
}], "Text"],

Cell[TextData[{
  StyleBox["Project IV. Write a report on how complex analysis is used to \
study the Mandelbrot set.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  "\n\n",
  StyleBox["1.",
    FontWeight->"Bold"],
  " Bridger, Mark, (1988), ''Looking at the Mandelbrot Set,'' Coll. Math. J., \
V. 19, No. 4, pp. 353-363.\n\n",
  StyleBox["2.",
    FontWeight->"Bold"],
  " Crowe, W. D. and R. Hasson and P. J. Rippon and P. E. D. Strain-Clark, \
(1989), ''On the Structure of the Mandelbar Set,'' Nonlinearity, V. 2, pp. \
541-553\n\n",
  StyleBox["3.",
    FontWeight->"Bold"],
  " Devaney, Robert L., (1991), ''The Orbit Diagram and the Mandelbrot Set,'' \
Coll. Math. J., V. 22, No. 1, pp. 23-38.\n\n",
  StyleBox["4.",
    FontWeight->"Bold"],
  " Ewing, John, (1995), ''Can We See the Mandelbrot Set?,'' College Math J.: \
Volume 26, Number 2, Pages: 90-99.\n\n",
  StyleBox["5.",
    FontWeight->"Bold"],
  " Frantz, Marny and Sylvia Lazarnick, (1991), ''The Mandelbrot Set in the \
Classroom,'' The Math. Teach., V. 84, No. 3, pp. 173-177."
}], "Text"],

Cell[TextData[{
  StyleBox["Project V. Write a report on how complex functions are used in \
the study of chaos.",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0, 0.996109]],
  "\n\n",
  StyleBox["1.",
    FontWeight->"Bold"],
  " Barton, Ray, (1990), ''Chaos and Fractals,'' Math. Teach., V. 83, No. 7, \
pp. 524-529.\n\n",
  StyleBox["2.",
    FontWeight->"Bold"],
  " Devaney, Robert L., (1987), ''Chaotic Bursts in Nonlinear Dynamical \
Systems, Science, V. 235, pp. 342-345.\n\n",
  StyleBox["3.",
    FontWeight->"Bold"],
  " Devaney, Robert L. and Linda Keen, (Editors), (1989), Chaos and Fractals: \
The Math. Behind the Computer Graphics, Providence R.I., Amer. Math. Soc.\n\n\
",
  StyleBox["4.",
    FontWeight->"Bold"],
  " Devaney, Robert L. and Marilyn B. Durkin, ''The Exploding Exponential and \
Other Chaotic Bursts in Complex Dynamics,'' Am. Math. M., Vol. 98, No. 3. \
(Mar., 1991), pp. 217-233, ",
  StyleBox[ButtonBox["Jstor.",
    ButtonData:>{
      URL[ "http://www.jstor.org/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "   .\n\n",
  StyleBox["5.",
    FontWeight->"Bold"],
  " Parris, Richard, (1991), ''The Root-Finding Route to Chaos,'' Coll. Math. \
J., V. 22, No. 1, pp. 48-55.\n\n",
  StyleBox["6.",
    FontWeight->"Bold"],
  " Strang, Gilbert, (1991), ''The Chaotic Search for i,'' Coll. Math. J., V. \
22, No. 1, pp. 3-12."
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Section 4.3",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0.250004, 0.250004]],
  StyleBox["  ",
    FontSize->16,
    FontWeight->"Bold"],
  StyleBox["Exercises for Julia and Mandelbrot Sets",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0.996109, 0.500008, 0.996109]],
  StyleBox["\n",
    FontSize->16,
    FontColor->RGBColor[1, 0, 1]],
  StyleBox["See textbook page 141. ",
    FontSize->16,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 1, 1]]
}], "Text"]
}, Closed]],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".3",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Geometric Series and Convergence Theorems",
    ButtonData:>{"ca0403.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["Section 4",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox[".4",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[0.500008, 0, 0.250004]],
  StyleBox["\t",
    FontFamily->"New Century Schlbk",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  StyleBox[ButtonBox["Power Series Functions",
    ButtonData:>{"ca0404.nb", None},
    ButtonStyle->"Hyperlink"],
    FontSize->14,
    FontWeight->"Bold"]
}], "Text"],

Cell[TextData[{
  StyleBox["GO TO  THE",
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[0, 0.996109, 0]],
  StyleBox["  ",
    FontSize->18,
    FontWeight->"Bold"],
  StyleBox[ButtonBox["Table of Contents",
    ButtonData:>{"content.nb", None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold"],
  "\n"
}], "Text"]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 800}, {0, 555}},
AutoGeneratedPackage->None,
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{769, 496},
WindowMargins->{{2, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, 128}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {15, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {10, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {15, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {10, 15}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {10, 20}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {10, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {8, 10}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output",
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageSize->{175, 175},
    ImageMargins->{{38, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageSize->{250, 250},
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    ScriptLevel->0,
    SingleLetterItalics->True,
    StyleMenuListing->None,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontSize->16,
    FontColor->RGBColor[1, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{1, -5},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "CHAPTER 4"->{
    Cell[4380, 143, 355, 12, 35, "Text",
      Evaluatable->False,
      CellTags->"CHAPTER 4"]},
  "Section 4.2"->{
    Cell[5899, 193, 10640, 141, 41, "Text",
      Evaluatable->False,
      CellTags->"Section 4.2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"CHAPTER 4", 81934, 2511},
  {"Section 4.2", 82051, 2515}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 615, 20, 109, "Text",
  Evaluatable->False],
Cell[2357, 73, 1986, 65, 248, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4380, 143, 355, 12, 35, "Text",
  Evaluatable->False,
  CellTags->"CHAPTER 4"],
Cell[4738, 157, 546, 9, 110, "Input",
  InitializationCell->True]
}, Closed]],
Cell[5299, 169, 575, 20, 32, "Text"],

Cell[CellGroupData[{
Cell[5899, 193, 10640, 141, 41, "Text",
  Evaluatable->False,
  CellTags->"Section 4.2"],
Cell[16542, 336, 2703, 78, 266, "Text"],
Cell[19248, 416, 475, 18, 74, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[19748, 438, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[19903, 444, 137, 5, 33, "Text"],
Cell[20043, 451, 992, 16, 317, "Input"],
Cell[21038, 469, 189, 8, 52, "Text"],
Cell[21230, 479, 552, 12, 130, "Input"],
Cell[21785, 493, 192, 8, 52, "Text"],
Cell[21980, 503, 795, 15, 206, "Input"],
Cell[22778, 520, 359, 12, 71, "Text"]
}, Closed]],
Cell[23152, 535, 333, 7, 90, "Text"],
Cell[23488, 544, 327, 11, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[23840, 559, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[23995, 565, 1214, 39, 127, "Text"]
}, Closed]],
Cell[25224, 607, 588, 21, 80, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[25837, 632, 167, 4, 33, "Text",
  Evaluatable->False],
Cell[26007, 638, 124, 5, 33, "Text"],
Cell[26134, 645, 1331, 28, 310, "Input"],
Cell[27468, 675, 625, 18, 80, "Text"],
Cell[28096, 695, 193, 3, 106, "Input"],
Cell[28292, 700, 291, 6, 80, "Text"],
Cell[28586, 708, 788, 13, 251, "Input"],
Cell[29377, 723, 214, 8, 52, "Text"],
Cell[29594, 733, 750, 13, 232, "Input"]
}, Closed]],
Cell[30359, 749, 1947, 56, 174, "Text"],
Cell[32309, 807, 374, 14, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32708, 825, 152, 4, 33, "Text",
  Evaluatable->False],
Cell[32863, 831, 540, 16, 52, "Text",
  Evaluatable->False]
}, Closed]],
Cell[33418, 850, 1833, 67, 170, "Text"],
Cell[35254, 919, 473, 16, 71, "Text",
  Evaluatable->False],
Cell[35730, 937, 319, 11, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[36074, 952, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[36230, 958, 178, 5, 33, "Text"],
Cell[36411, 965, 717, 13, 210, "Input"],
Cell[37131, 980, 435, 11, 71, "Text"]
}, Closed]],
Cell[37581, 994, 210, 8, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[37816, 1006, 167, 4, 33, "Text",
  Evaluatable->False],
Cell[37986, 1012, 180, 7, 33, "Text",
  Evaluatable->False],
Cell[38169, 1021, 417, 6, 154, "Input"],
Cell[38589, 1029, 483, 13, 71, "Text",
  Evaluatable->False],
Cell[39075, 1044, 505, 9, 166, "Input"]
}, Closed]],
Cell[39595, 1056, 825, 21, 153, "Text"],
Cell[40423, 1079, 325, 11, 55, "Text",
  Evaluatable->False],
Cell[40751, 1092, 172, 6, 33, "Text",
  Evaluatable->False],
Cell[40926, 1100, 154, 4, 52, "Text"],
Cell[41083, 1106, 348, 13, 52, "Text",
  Evaluatable->False],
Cell[41434, 1121, 391, 13, 52, "Text",
  Evaluatable->False],
Cell[41828, 1136, 799, 30, 71, "Text",
  Evaluatable->False],
Cell[42630, 1168, 180, 4, 33, "Text",
  Evaluatable->False],
Cell[42813, 1174, 823, 22, 113, "Text"],
Cell[43639, 1198, 573, 18, 71, "Text",
  Evaluatable->False],
Cell[44215, 1218, 180, 4, 33, "Text",
  Evaluatable->False],
Cell[44398, 1224, 540, 19, 71, "Text",
  Evaluatable->False],
Cell[44941, 1245, 623, 20, 90, "Text",
  Evaluatable->False],
Cell[45567, 1267, 458, 14, 71, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[46050, 1285, 153, 4, 33, "Text",
  Evaluatable->False],
Cell[46206, 1291, 312, 11, 33, "Text"],
Cell[46521, 1304, 1188, 21, 334, "Input"],
Cell[47712, 1327, 157, 5, 52, "Text"]
}, Closed]],
Cell[47884, 1335, 215, 8, 52, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[48124, 1347, 167, 4, 33, "Text",
  Evaluatable->False],
Cell[48294, 1353, 264, 8, 71, "Text",
  Evaluatable->False],
Cell[48561, 1363, 408, 6, 134, "Input"],
Cell[48972, 1371, 422, 12, 52, "Text",
  Evaluatable->False],
Cell[49397, 1385, 430, 6, 150, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[49864, 1396, 166, 3, 37, "Text"],
Cell[50033, 1401, 569, 15, 113, "Text"],
Cell[50605, 1418, 1850, 47, 402, "Text"],
Cell[52458, 1467, 846, 23, 136, "Text"],
Cell[53307, 1492, 1108, 28, 246, "Text"],
Cell[54418, 1522, 1424, 39, 307, "Text"]
}, Closed]],
Cell[55857, 1564, 547, 19, 60, "Text"]
}, Closed]],
Cell[56419, 1586, 596, 20, 32, "Text"],
Cell[57018, 1608, 577, 20, 35, "Text"],
Cell[57598, 1630, 339, 13, 57, "Text"]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

